@@ -248,4 +248,5 @@ class DockerBuildHelper:
         remote_branch = 'master'
         if self.git('ls-remote', remote, remote_branch):
             raise DeploymentBranchAlreadyExisting(url, remote_branch)
-        self.git('push', '-q', '--set-upstream', remote, remote_branch)
+        return self.git('push', '-q', '--set-upstream', remote, remote_branch,
+                        stderr=subprocess.STDOUT)
