@@ -159,6 +159,8 @@ class PaasDispatcher:
         self.init_intervals(config)
         self.finished_jobs_keep_resources = config.get(
             'paas_finished_jobs_keep_resources', False)
+        self.decommission_launch_failures = config.get(
+            'paas_decommission_launch_failures', True)
 
         self.reporting_queue = Queue()
 
@@ -314,8 +316,11 @@ class PaasDispatcher:
                 self.launched_jobs.add(job_handle)
                 self.pending_jobs.pop(job_handle, None)
                 self.total_job_launches += 1
-                logger.info("Successfullly launched %s (final weight %.1f)",
-                            job_handle, job_handle.paas_resource.weight)
+                launch_time = msg[2]
+                logger.info("Successfully launched %s in %d seconds "
+                            "(final weight %.1f)",
+                            job_handle, launch_time,
+                            job_handle.paas_resource.weight)
             elif status is JobEventType.LAUNCH_FAILED:
                 self.potential_concurrency -= 1
                 self.potential_weight -= job_handle.expected_weight
@@ -323,18 +328,26 @@ class PaasDispatcher:
                 logger.error("Failed to launch %s", job_handle)
                 self.total_job_launches += 1
                 self.launch_errors.append(job_handle)
+                if self.decommission_launch_failures:
+                    self.schedule_decommission(job_handle)
             elif status is JobEventType.COORDINATOR_REPORT_FAILED:
                 # event supersedes LAUNCH_FAILED (adds info that reporting
                 # the failure itself failed)
                 self.potential_concurrency -= 1
                 self.potential_weight -= job_handle.expected_weight
+                self.pending_jobs.pop(job_handle, None)
+                logger.error("Failed to launch %s and even report it "
+                             "to coordinator", job_handle)
+                self.total_job_launches += 1
+                self.launch_errors.append(job_handle)
+                if self.decommission_launch_failures:
+                    self.schedule_decommission(job_handle)
             elif status is JobEventType.FINISHED:
                 logger.info("Finished %s, according to "
                             "coordinator.", job_handle)
                 self.launched_jobs.discard(job_handle)
                 if not self.finished_jobs_keep_resources:
-                    self.to_decommission.add(job_handle)
-                    self.start_decommission_thread(job_handle)
+                    self.schedule_decommission(job_handle)
             elif status is JobEventType.DECOMMISSIONED:
                 self.potential_concurrency -= 1
                 self.potential_weight -= job_handle.paas_resource.weight
@@ -389,6 +402,7 @@ class PaasDispatcher:
         except Exception:
             logger.exception("Unexpected exception for %s", job_handle)
         else:
+            start = time.time()
             try:
                 if not runner.job_wait_trace(
                         job_data['job_info']['project_id'],
@@ -402,16 +416,32 @@ class PaasDispatcher:
                              "set to %d seconds)", job_handle, timeout)
                 # TODO if the job is finished (cancelled etc), then GitLab
                 # will probably return a 40x error on this.
-                runner.job_append_trace(
-                    job_handle,
-                    colour.red(f"Job not active (no log) after {timeout} "
-                               f"seconds" + '\n')
-                )
+                try:
+                    runner.job_append_trace(
+                        job_handle,
+                        colour.red(f"Job not active (no log) after {timeout} "
+                                   f"seconds" + '\n')
+                    )
+                except Exception:
+                    logger.exception(
+                        "Could not append timeout trace to job %r "
+                        "it will be considered as failed to launch "
+                        "but chances are that it is already finished "
+                        "on GitLab side", job_handle)
+            except Exception:
+                logger.exception(
+                    "Could not fetch trace for job %r from coordinator "
+                    "it will be considered as failed to launch "
+                    "but chances are that it is already finished "
+                    "on GitLab side", job_handle)
             else:
                 success = True
+                elapsed = time.time() - start
 
+        details = ()
         if success:
             in_process_status = JobEventType.LAUNCHED
+            details = (elapsed, )
         else:
             # script_failure is formally incorrect, but it triggers no special
             # banner rendering, whereas all other currently available values
@@ -421,7 +451,7 @@ class PaasDispatcher:
             # temporary provisioning errors, though.
             in_process_status = self.report_coordinator_job_failed(
                 job_handle, reason='script_failure')
-        reporting_queue.put((job_handle, in_process_status))
+        reporting_queue.put((job_handle, in_process_status) + details)
 
     def decommission(self, job_handle):
         resource = job_handle.paas_resource
@@ -442,6 +472,13 @@ class PaasDispatcher:
             self.reporting_queue.put(
                 (job_handle, JobEventType.DECOMMISSIONED))
 
+    def schedule_decommission(self, job_handle):
+        if job_handle.paas_resource is None:
+            return
+
+        self.to_decommission.add(job_handle)
+        self.start_decommission_thread(job_handle)
+
     def report_coordinator_job_failed(self, job_handle, reason):
         """Report failure with exception catching and retry logic.
 
